@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Cxn::AEHTTP;
-$Search::Elasticsearch::Cxn::AEHTTP::VERSION = '1.13';
+$Search::Elasticsearch::Cxn::AEHTTP::VERSION = '1.15';
 use AnyEvent::HTTP qw(http_request);
 use Promises qw(deferred);
 use Try::Tiny;
@@ -10,8 +10,19 @@ with 'Search::Elasticsearch::Role::Cxn::HTTP',
     'Search::Elasticsearch::Role::Cxn',
     'Search::Elasticsearch::Role::Is_Async';
 
+has '_tls_ctx' => ( is => 'lazy' );
+
 use namespace::clean;
 
+#===================================
+sub _build__tls_ctx {
+#===================================
+    my $self = shift;
+    return 'low' unless $self->has_ssl_options;
+    require AnyEvent::TLS;
+    return AnyEvent::TLS->new( %{ $self->ssl_options } );
+}
+
 #===================================
 sub perform_request {
 #===================================
@@ -33,6 +44,7 @@ sub perform_request {
         body => $data,
         persistent => 0,
         session    => $self->_pid,
+        ( $self->is_https ? ( tls_ctx => $self->_tls_ctx ) : () ),
         sub {
             my ( $body, $headers ) = @_;
             try {
@@ -80,7 +92,7 @@ Search::Elasticsearch::Cxn::AEHTTP - An async Cxn implementation which uses AnyE
 
 =head1 VERSION
 
-version 1.13
+version 1.15
 
 =head1 DESCRIPTION
 
@@ -128,6 +140,48 @@ From L<Search::Elasticsearch::Role::Cxn>
 
 =back
 
+=head1 SSL/TLS
+
+L<Search::Elasticsearch::Cxn::AEHTTP> uses L<AnyEvent::TLS> to support
+HTTPS.  By default, no validation of the remote host is performed.
+
+This behaviour can be changed by passing the C<ssl_options> parameter
+with any options accepted by L<AnyEvent::TLS>. For instance, to check
+that the remote host has a trusted certificate, and to avoid man-in-the-middle
+attacks, you could do the following:
+
+    use Search::Elasticsearch::Async;
+
+    my $es = Search::Elasticsearch::Async->new(
+        nodes => [
+            "https://node1.mydomain.com:9200",
+            "https://node2.mydomain.com:9200",
+        ],
+        ssl_options => {
+            verify              => 1,
+            verify_peername     => 'https'
+            ca_file             => '/path/to/cacert.pem'
+        }
+    );
+
+If you want your client to present its own certificate to the remote
+server, then use:
+
+    use Search::Elasticsearch::Async;
+
+    my $es = Search::Elasticsearch::Async->new(
+        nodes => [
+            "https://node1.mydomain.com:9200",
+            "https://node2.mydomain.com:9200",
+        ],
+        ssl_options => {
+            verify              => 1,
+            verify_peername     => 'https'
+            ca_file             => '/path/to/cacert.pem'
+            cert_file           => '/path/to/client.pem',
+        }
+    );
+
 =head1 METHODS
 
 =head2 C<perform_request()>
