@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Cxn::Mojo;
-$Search::Elasticsearch::Cxn::Mojo::VERSION = '1.13';
+$Search::Elasticsearch::Cxn::Mojo::VERSION = '1.15';
 use Mojo::UserAgent();
 use Promises qw(deferred);
 use Try::Tiny;
@@ -41,15 +41,20 @@ sub perform_request {
         $tx,
         sub {
             my ( $ua, $tx ) = @_;
-            my $res     = $tx->res;
+            my $res = $tx->res;
+            my $error;
+            if ( $error = $res->error ) {
+                $error = $error->{message}
+                    if ref $error eq 'HASH';
+            }
+
             my $headers = $res->headers->to_hash;
             $headers->{ lc($_) } = delete $headers->{$_} for keys %{$headers};
-
             try {
                 my ( $code, $response ) = $self->process_response(
                     $params,    # request
                     ( $res->code || 500 ),    # status
-                    $res->message,            # reason
+                    $error,                   # reason
                     $res->body,               # content
                     $headers,                 # headers
                 );
@@ -74,9 +79,18 @@ sub error_from_text {
 }
 
 #===================================
-sub _build_handle { Mojo::UserAgent->new }
+sub _build_handle {
 #===================================
-
+    my $self = shift;
+    my $ua   = Mojo::UserAgent->new;
+    if ( $self->is_https && $self->has_ssl_options ) {
+        my %opts = %{ $self->ssl_options };
+        for ( keys %opts ) {
+            $ua = $ua->$_( $opts{$_} );
+        }
+    }
+    return $ua;
+}
 1;
 
 # ABSTRACT: An async Cxn implementation which uses Mojo::UserAgent
@@ -93,7 +107,7 @@ Search::Elasticsearch::Cxn::Mojo - An async Cxn implementation which uses Mojo::
 
 =head1 VERSION
 
-version 1.13
+version 1.15
 
 =head1 DESCRIPTION
 
@@ -147,6 +161,46 @@ From L<Search::Elasticsearch::Role::Cxn>
 
 =back
 
+=head1 SSL/TLS
+
+L<Search::Elasticsearch::Cxn::Mojo> does no validation of the remote host by default.
+
+This behaviour can be changed by passing the C<ssl_options> parameter
+with the C<ca>, C<cert>, and C<key> options. For instance, to check
+that the remote host has a trusted certificate, and to avoid man-in-the-middle
+attacks, you could do the following:
+
+    use Search::Elasticsearch::Async;
+
+    my $es = Search::Elasticsearch::Async->new(
+        cxn   => 'Mojo',
+        nodes => [
+            "https://node1.mydomain.com:9200",
+            "https://node2.mydomain.com:9200",
+        ],
+        ssl_options => {
+            ca  => '/path/to/cacert.pem'
+        }
+    );
+
+If you want your client to present its own certificate to the remote
+server, then use:
+
+    use Search::Elasticsearch::Async;
+
+    my $es = Search::Elasticsearch::Async->new(
+        cxn   => 'Mojo',
+        nodes => [
+            "https://node1.mydomain.com:9200",
+            "https://node2.mydomain.com:9200",
+        ],
+        ssl_options => {
+            ca   => '/path/to/cacert.pem'
+            cert => '/path/to/client.pem',
+            key  => '/path/to/client.pem'
+        }
+    );
+
 =head1 METHODS
 
 =head2 C<perform_request()>
